from setuptools import find_packages, setup

setup(name="python_web_exceptions",
      version='1.0',
      description="Framework agnostic web exceptions for python",
      author="Aaron Martin",
      url="https://github.com/ajmar3/python-web-exceptions",
      license="MIT",
      packages=find_packages()
      )

